#include <ESP8266WiFi.h>
#include <OneWire.h>
#include <DallasTemperature.h>

#define errorPin 16
// Data wire is plugged into pin D1
#define ONE_WIRE_BUS D1

// Setup a oneWire instance to communicate with any OneWire devices
OneWire oneWire(ONE_WIRE_BUS);

// Pass our oneWire reference to Dallas Temperature. 
DallasTemperature sensors(&oneWire);

// Assign the addresses of your 1-Wire temp sensors.
DeviceAddress R = { 0x28, 0xFF, 0x85, 0xE6, 0x61, 0x16, 0x03, 0xBB };
DeviceAddress G = { 0x28, 0xFF, 0xDB, 0x8F, 0x61, 0x16, 0x03, 0x8F };
DeviceAddress Y = { 0x28, 0xFF, 0x3C, 0x28, 0x62, 0x16, 0x03, 0xCF };
DeviceAddress B = { 0x28, 0xFF, 0x77, 0x8F, 0x61, 0x16, 0x03, 0x9D };
DeviceAddress W = { 0x28, 0xFF, 0x36, 0xC5, 0x61, 0x16, 0x03, 0x42 };

DeviceAddress temp1,temp2,temp3,temp4,temp5;

// Define and initialize constants and variables that we'll use later in the code
const int sleep_time = 20;  // Time to sleep (in seconds) between posts to Ubidots
WiFiClient client;

// Ubidots variables,
String variable_id1 = "";
String variable_id2 = "";
String variable_id3 = "";
String variable_id4 = "";
String variable_id5 = "";

// API token here
String token = "";

// We'll also initialize the values for our Wi-Fi network
const char* ssid = "";  // WiFi ssid here
const char* password = ""; //password 

//////////////////////////////////////////////////////////////////////////////////
// The setup function is executed once by the ESP8266 when it's powered up or reset
void setup()
{
  pinMode(errorPin, OUTPUT); // sets pin as an output to drive an LED for status indication
  // The following loop flashes the LED four times to indicate we're inside the setup function
  for (int i=0;i<4; i++)
  {
    digitalWrite(errorPin ,HIGH);
    delay(200);
    digitalWrite(errorPin ,LOW);
    delay(200);
  }

  // Initialize Serial (USB) communication, which will be used for sending debugging messages
  // to the computer
  Serial.begin(115200);
  // Start up the library
  sensors.begin();

    // Manual delay while the communication with the sensor starts
  delay(10);

  // Debug messsages to indicate we're about to connect to the network
   Serial.println();
  Serial.print("Connecting to ");
  Serial.println(ssid);

  // Use the scanNetworks method inside the Wi-Fi class to scan for any available Wi-Fi networks
  // nearby. If none are found, go to sleep
  int n = WiFi.scanNetworks();

  Serial.println("scan done"); 
  if (n == 0)
  {
    Serial.println("no networks found");
    Serial.println("Going into sleep");
  }

  // If networks are found, attempt to connect to our Wi-Fi network
  WiFi.begin(ssid, password);

  // While the connection is not established, IDLE inside this while loop
  while (WiFi.status() != WL_CONNECTED)
  {
    delay(500);
    Serial.print(".");
  }

  // Once the connection to our Wi-Fi netowrk is successful, print some debug messages
  Serial.println("");
  Serial.println("Wi-Fi connected");
}
void printTemperature(DeviceAddress deviceAddress)
{
  float tempC = sensors.getTempC(deviceAddress);
  if (tempC == -127.00) {
    Serial.print("Error getting temperature");
  } else {
    Serial.print("C: ");
    Serial.print(tempC);    
  }
}

////////////////////////////////////////////////////////////////////////////////
// Main code
void loop()
{
  delay(4000);
  Serial.print("Getting temperatures...\n\r");
  sensors.requestTemperatures();
  
  Serial.print("R is: ");
  printTemperature(R);
  Serial.print("\n\r");
  Serial.print("G is: ");
  printTemperature(G);
  Serial.print("\n\r");
  Serial.print("Y is: ");
  printTemperature(Y);
  Serial.print("\n\r");
  Serial.print("B is: ");
  printTemperature(B);
  Serial.print("\n\r");
  Serial.print("W is: ");
  printTemperature(W);
  Serial.print("\n\r\n\r");


}

